/*//////////////////////////////////////////
/
	* lequene-bsm v3.3.7 (http://github.com/HassanKrayem/modalup)
	* Copyright 2016-2018
	* Licensed under the MIT license
	 
	Author: Hassan Krayem
	Email: developer.hassankrayem@gmail.com	
	Version: 2.3.2
	Description: Plugin for bootstrap that gives the ablility to create
	modals with ease using only javascript.

*//////////////////////////////////////////

function lequene(props)
{
	/*
		props {
			
			id:"" (Require),
			modalSize : "modal-sm" / "modal-lg" or leave it empty for medium size,
			headerCancelButton: true / false (optional),
			FooterCancelButton: true / false  (optional),
			ConfirmButton: true / false  (optional),
			ConfirmButtonFunc: function(){}  (optional),
			ConfirmButtonText: ""  (optional),
			ConfirmButtonClass: e.g. "btn-info"  (optional),
			footerCloseButtonText: default "close",
			titlePrefix: "" / null  (optional),
			titlePostfix: "" / null  (optional),
			clearModal: true / false,
			closeOnConfirm: true / false,
			closeByEscKey: true / false, // close the modal when the user press the Esc on keyboard
			closeByCodeOnly: true / false, // modal can't be closed when the user click anywhere on the screen  it must be dismissed by a code / close button
			onOpen : function(){}
			onClose : function(){}			
		}
	*/
	
	if(!props.id)
		return false;
	
	var O = this;
	this.titlePrefix = "";
	this.titlePostfix = "";
	this.confirmButtonFunc = function(){};
	this.onOpen = function(){};
	this.onClose = function(){};
	
	if(props.ConfirmButtonFunc)
	{
		
		this.confirmButtonFunc = props.ConfirmButtonFunc;
		
	}
	
	if(props.onOpen && typeof props.onOpen == "function")
	{
		this.onOpen = props.onOpen;
	}
	
	if(props.titlePrefix)
	{
		this.titlePrefix = props.titlePrefix;
	}	
	
	if(props.titlePostfix)
	{
		this.titlePostfix = props.titlePostfix;
	}	
	
	var modalID = props.id
	var modal = document.createElement("div");
	modal.setAttribute("id",modalID);
	modal.setAttribute("class","modal fade");
	modal.setAttribute("role","dialog");
	
	if(props.closeByEscKey && props.closeByEscKey == false)
	{
		
		modal.setAttribute("data-keyboard","false");
		
	}
	
	if(props.closeByCodeOnly && props.closeByCodeOnly == true)
	{
		
		modal.setAttribute("data-backdrop","static");
		
	}
	
	var modalDialog = document.createElement("div");
	var t_modalSize = props.modalSize || "modal-lg";
	
	if(t_modalSize != "modal-lg" || t_modalSize != "modal-sm" || t_modalSize != "modal-md")
	{
		
		t_modalSize = "modal-lg";
		
	}

	
	modalDialog.setAttribute("class","modal-dialog " + t_modalSize);	
	modal.appendChild(modalDialog);
	
	//child of modalDialog
	var modaContent = document.createElement("div");
	modaContent.setAttribute("class","modal-content");
	if(props.clearModal)
	{
		
		modaContent.style.background = "transparent";
		modaContent.style.boxShadow = "none";
		modaContent.style.border = "none";
		
		
	}
	
	//child of modaContent
	var modalHeader = document.createElement("div");
	modalHeader.setAttribute("class","modal-header");
	if(props.clearModal)
	{
		modalHeader.style.border = "none";
	}
	
	this.header = modalHeader;
	
	modaContent.appendChild(modalHeader);
	
	if(props.headerCancelButton)
	{
		//child of modalHeader
		var modalHeaderButton = document.createElement("button");
		modalHeaderButton.setAttribute("class","close");
		modalHeaderButton.setAttribute("data-dismiss","modal");
		modalHeaderButton.innerHTML = "&times;";
		modalHeader.appendChild(modalHeaderButton);
	}
	
	
	//child of modalHeader
	var modalHeaderTitle = document.createElement("h4");
	modalHeaderTitle.setAttribute("class","modal-title");
	modalHeaderTitle.setAttribute("id",modalID + "-title");
	modalHeader.appendChild(modalHeaderTitle);
	
	
	var modalBody = document.createElement("div");
	modalBody.setAttribute("class","modal-body");
	modalBody.setAttribute("id",modalID + "-body");	
	
	this.body = modalBody;
	
	modaContent.appendChild(modalBody);
	
	var modalFooter = document.createElement("div");
	modalFooter.setAttribute("class","modal-footer");
	modalFooter.setAttribute("id",modalID + "-footer");
	if(props.clearModal)
	{
		modalFooter.style.border = "none";
	}
	this.footer = modalFooter;
	
	if(props.footerCancelButton)
	{
		
		//child of modalFooter
		var modalFooterButton = document.createElement("button");
		modalFooterButton.setAttribute("type","button");
		modalFooterButton.setAttribute("class","btn btn-default");
		modalFooterButton.setAttribute("data-dismiss","modal");
		modalFooterButton.innerHTML = (props.footerCloseButtonText)?props.footerCloseButtonText : "Close";
		modalFooter.appendChild(modalFooterButton);
		
	}
	
	if(props.ConfirmButton)
	{
		
		//child of modalFooter
		var modalFooterConfirmButton = document.createElement("button");
		modalFooterConfirmButton.setAttribute("type","button");
		modalFooterConfirmButton.setAttribute("class","btn " + ((props.ConfirmButtonClass)?props.ConfirmButtonClass:"btn-primary"));
		if(props.closeOnConfirm && props.closeOnConfirm == true)
		{
			modalFooterConfirmButton.setAttribute("data-dismiss","modal");
		}
		modalFooterConfirmButton.innerHTML = (props.ConfirmButtonText)?props.ConfirmButtonText:"Confirm";
		modalFooterConfirmButton.onclick = function()
		{
						
				O.confirmButtonFunc();
			
		}
		
		modalFooter.appendChild(modalFooterConfirmButton);
		
	}
	
	

	// var modalBtn = document.createElement("button");	
	// modalBtn.setAttribute("id",modalID + "-btn");
	// modalBtn.setAttribute("type","button");
	// modalBtn.setAttribute("class","btn");
	// modalBtn.setAttribute("data-toggle","modal");
	// modalBtn.setAttribute("data-target","#" + modalID);
	// modalBtn.style.display = "none";

	
	modaContent.appendChild(modalFooter);
	modalDialog.appendChild(modaContent);	
	
	
	this.born = function()
	{
		
		//document.body.appendChild(modalBtn);
		document.body.appendChild(modal);
		if(props.onClose && typeof props.onClose == "function")
		{
			//this.onClose = props.onClose;
			$('#' + props.id).on('hidden.bs.modal', function () {
			    props.onClose();
			})
		}
	
		
	}
	
		
	
	this.setConfirmBtnFunc = function(func)
	{
		
		this.confirmButtonFunc = func;
		
	}
	
	this.setTitle = function(newTitle)
	{
		
		modalHeaderTitle.innerHTML = this.titlePrefix + newTitle + this.titlePostfix;
		
	}
	
	this.setBody = function(newBody,callback,jscode)
	{
		
		var extra = "";
		
		// if(jscode && typeof jscode == "function")
		// {
			// extra = "<script type='text/javascript'>("+ jscode +")();</script>";
		// }
		
		modalBody.innerHTML = (newBody);
		this.evalJSFromHtml(newBody);
		if(callback && typeof callback == "function")
		{
			callback(newBody);
		}
		
	}
	
	this.setFooter = function(newFooter)
	{
		
		modalFooter.innerHTML = newFooter;
		
	}
	
	
	this.appendChild = function(child,part)
	{
		
		var p = O.body;
		switch(part)
		{
			case "header" : p = O.header;break;
			case "footer" : p = O.footer;break;
		}
		
		p.appendChild(child);
		
	}
	
	this.open = function()
	{
	
		O.onOpen();
		$('#' + props.id).modal('toggle');
		//modalBtn.click();
		
	}
	
	this.close = function()
	{
	
		$('#' + props.id).modal('hide');
		
	}
	
	this.toggle = function()
	{
		
		$('#' + props.id).modal('toggle');
		
	}
	
	this.setLoader = function()
	{
		
		modal.setAttribute("data-backdrop","static");
		modal.setAttribute("data-keyboard","false");
		O.setBody('<div class="bootstrap-modal-creator-spin"></div><br><br>')
		
	}
	
	this.evalJSFromHtml = function(html)
	{
		
		var newElement = document.createElement('div');
		newElement.innerHTML = html;

		var scripts = newElement.getElementsByTagName("script");
		for(var i = 0; i < scripts.length; ++i) {
			
			var script = scripts[i];
			eval(script.innerHTML);	
			
		}				
		
	}

	this.remove = function()
	{
		$('#'+modalID).remove();
	}
	
	// note invoking this method once is enough for the rest of modals instances.
	// note if the body scroll is gone, that means there is an open hidden modal
	this.supportMultipleModals = function()
	{
		
		$('body').on('hidden.bs.modal', function (a) {
			//alert(a.target.get)
			
			if ($('.modal:visible').length) { // check whether parent modal is opend after child modal close
				$('body').addClass('modal-open'); // if open mean length is 1 then add a bootstrap css class to body of the page
			}
			else
			{
				$('body').removeClass('modal-open');
				$('body').css('padding-right','0px');
			}
			
		});
		
		
	}

	return this;
	
}

/* example

	var modalProfileEditor = createBootstrapModal(
	{
			id:"modal-profile-editor",
			headerCancelButton:true,
			footerCancelButton:true,
			titlePrefix:"Viewing: "
	});
 
	modalProfileEditor.born();
	modalProfileEditor.setTitle("neotion@Outlook.com");
	modalProfileEditor.open();

*/
